
TODO: TODO_43_41_95_86: use server logger to disable stdout

Local test has to re-run printing for stdout capturing after receiving response from the server
because capturing it earlier will also capture server output.

If server can use logger everywhere, it might be possible to redirect its output to /dev/null or equivalent
and simplify test setup.

